@@ -23,6 +23,8 @@ except ImportError:  # pragma: nocover
 from fastapi_crawler_scheduler.utils.exception import SchedulerError
 from fastapi_crawler_scheduler.service.dbRedisHelper import DbRedisHelper
 from fastapi_crawler_scheduler.service.baseScheduler import BaseScheduler
+from fastapi_crawler_scheduler.utils.objectToString import handle_trigger
+from fastapi_crawler_scheduler.utils.objectToString import handle_datetime
 
 
 class TaskScheduler(object):
@@ -204,3 +206,90 @@ class TaskScheduler(object):
             job_id: str,
     ) -> None:
         self.register_base_scheduler.delete_task(job_id=job_id)
+
+    def get_all_apscheduler_stores_jobs(self):
+        redis_apscheduler_jobs_dict = dict()
+        for apscheduler_stores_job_key in self.register_redis_db.get_stores_job_task():
+            value_dict = dict()
+            job_states_byte_dict = self.redis_job_store.redis.hgetall(apscheduler_stores_job_key)
+            for job_states_key_byte, job_states_value_byte in job_states_byte_dict.items():
+                job_states_key = job_states_key_byte.decode()
+                job_states_value = pickle.loads(job_states_value_byte)
+                # print(f"handle_before： {job_states_value}")
+                if 'trigger' in job_states_value:
+                    # todo: combining 情况下有问题
+                    trigger = job_states_value['trigger'].__getstate__()
+                    job_states_value['trigger'] = handle_trigger(trigger)
+                if 'next_run_time' in job_states_value:
+                    job_states_value['next_run_time'] = handle_datetime(agefield=job_states_value.get('next_run_time'))
+                # print(f"handle_after： {job_states_value}")
+                value_dict[job_states_key] = job_states_value
+            redis_apscheduler_jobs_dict[apscheduler_stores_job_key] = value_dict
+        return redis_apscheduler_jobs_dict
+
+    def get_all_redis_tasks(self):
+        all_tasks = dict()
+        for all_task_key in self.register_redis_db.connection.keys(pattern=f'{self.project_name}:all:*'):
+            value = self.register_redis_db.from_key_get_value(all_task_key)
+            all_tasks[all_task_key] = value
+        return all_tasks
+
+    def get_all_redis_apscheduler_run_times(self):
+        redis_apscheduler_run_time_dict = dict()
+        for apscheduler_run_time_key in self.register_redis_db.get_stores_job_run_time_task():
+            value_dict = dict()
+            apscheduler_run_time_byte_list = self.redis_job_store.redis.zrange(
+                apscheduler_run_time_key, 0, 4821384687, withscores=True)
+            for job_states_key_byte, run_time__byte_timestamp in apscheduler_run_time_byte_list:
+                job_states_key = job_states_key_byte.decode()
+                value_dict[job_states_key] = run_time__byte_timestamp
+            redis_apscheduler_run_time_dict[apscheduler_run_time_key] = value_dict
+        return redis_apscheduler_run_time_dict
+
+    def show_all_redis_key(self):
+        return self.register_redis_db.connection.keys(pattern=f'{self.project_name}:*')
+
+    def show_all_redis_nodes(self):
+        node_dict = dict()
+        for node_key in self.register_redis_db.connection.keys(pattern=f'{self.project_name}:node:*'):
+            value = self.register_redis_db.connection.get(node_key)
+            node_dict[node_key] = value
+        return node_dict
+
+    def show_all_redis_tasks(self):
+        return self.get_all_redis_tasks()
+
+    def show_all_scheduler_get_jobs(self):
+        all_tasks = dict()
+        for all_task_key in self.register_redis_db.connection.keys(pattern=f'{self.project_name}:running_job:*'):
+            value = dict()
+            value['approximate_start_time'] = self.register_redis_db.connection.get(all_task_key)
+            value['data_ttl'] = self.register_redis_db.connection.ttl(all_task_key)
+            all_tasks[all_task_key] = value
+        return all_tasks
+
+    def show_all_apscheduler_stores_jobs(self):
+        return self.get_all_apscheduler_stores_jobs()
+
+    def show_all_redis_apscheduler_run_times(self):
+        return self.get_all_redis_apscheduler_run_times()
+
+    def show_all_task_not_in_stores_jobs(self):
+        problem_task = {}
+        redis_apscheduler_job_id_list = []
+        for redis_apscheduler_jobs_value in self.get_all_apscheduler_stores_jobs().values():
+            redis_apscheduler_job_id_list.extend(redis_apscheduler_jobs_value.keys())
+        for all_key, all_value in self.get_all_redis_tasks().items():
+            if all_value.get('job_id') not in redis_apscheduler_job_id_list:
+                problem_task[all_key] = all_value
+        return problem_task
+
+    def show_all_task_not_in_stores_run_times(self):
+        problem_task = {}
+        redis_apscheduler_run_time_job_id_list = []
+        for redis_apscheduler_job_run_time_value in self.get_all_redis_apscheduler_run_times().values():
+            redis_apscheduler_run_time_job_id_list.extend(redis_apscheduler_job_run_time_value.keys())
+        for all_key, all_value in self.get_all_redis_tasks().items():
+            if all_value.get('job_id') not in redis_apscheduler_run_time_job_id_list:
+                problem_task[all_key] = all_value
+        return problem_task
